Documentation
¶
Overview ¶
Package linewrap provides basic support for wrapping text to a given width.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Comment ¶ added in v0.0.7
Comment wraps the supplied text to width indented by indent spaces with each line starting with the supplied comment string. It is intended for formatting source code comments.
func Paragraph ¶ added in v0.0.7
Paragraph wraps the supplied text as a 'paragraph' with separate indentation for the initial and subsequent lines to the specified width.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.